@@ -18,7 +18,7 @@ class Snumber:
 		Snippet: value: str = driver.base.multiCmw.snumber.fetch(box_nr = enums.BoxNumber.BOX1) \n
 		No command help available \n
 			:param box_nr: No help available
-			:return: serialnumber: No help available"""
+			:return: serial_number: No help available"""
 		param = Conversions.enum_scalar_to_str(box_nr, enums.BoxNumber)
 		response = self._core.io.query_str(f'FETCh:BASE:MCMW:SNUMber? {param}')
 		return trim_str_response(response)
