@@ -15,7 +15,7 @@ class Salignment:
 		"""SCPI: CATalog:BASE:SALignment:SLOT \n
 		Snippet: value: str = driver.catalog.base.salignment.get_slot() \n
 		No command help available \n
-			:return: slotlist: No help available
+			:return: slot_list: No help available
 		"""
 		response = self._core.io.query_str('CATalog:BASE:SALignment:SLOT?')
 		return trim_str_response(response)
