@@ -21,7 +21,7 @@ class Catalog:
 		Snippet: value: List[str] = driver.configure.base.freqCorrection.correctionTable.catalog.get(table_path = '1') \n
 		No command help available \n
 			:param table_path: No help available
-			:return: tablename: No help available"""
+			:return: table_name: No help available"""
 		param = ArgSingleList().compose_cmd_string(ArgSingle('table_path', table_path, DataType.String, True))
 		response = self._core.io.query_str(f'CONFigure:BASE:FDCorrection:CTABle:CATalog? {param}'.rstrip())
 		return Conversions.str_to_str_list(response)
