@@ -19,7 +19,7 @@ class Count:
 		Snippet: value: int = driver.configure.base.freqCorrection.correctionTable.count.get(table_path = '1') \n
 		No command help available \n
 			:param table_path: No help available
-			:return: tablecount: No help available"""
+			:return: table_count: No help available"""
 		param = ArgSingleList().compose_cmd_string(ArgSingle('table_path', table_path, DataType.String, True))
 		response = self._core.io.query_str(f'CONFigure:BASE:FDCorrection:CTABle:COUNt? {param}'.rstrip())
 		return Conversions.str_to_int(response)
