@@ -19,13 +19,13 @@ class Tx:
 			self._all = All(self._core, self._base)
 		return self._all
 
-	def set_value(self, connectorbench: str) -> None:
+	def set_value(self, connector_bench: str) -> None:
 		"""SCPI: CONFigure:CMWS:FDCorrection:DEACtivate:TX \n
-		Snippet: driver.configure.singleCmw.freqCorrection.deactivate.tx.set_value(connectorbench = r1) \n
+		Snippet: driver.configure.singleCmw.freqCorrection.deactivate.tx.set_value(connector_bench = r1) \n
 		No command help available \n
-			:param connectorbench: No help available
+			:param connector_bench: No help available
 		"""
-		param = Conversions.value_to_str(connectorbench)
+		param = Conversions.value_to_str(connector_bench)
 		self._core.io.write(f'CONFigure:CMWS:FDCorrection:DEACtivate:TX {param}')
 
 	def clone(self) -> 'Tx':
