@@ -13,13 +13,13 @@ class Item:
 		self._core = core
 		self._base = CommandsGroup("item", core, parent)
 
-	def set(self, item_path: str, file_name: str) -> None:
+	def set(self, item_path: str, filename: str) -> None:
 		"""SCPI: MMEMory:LOAD:ITEM \n
-		Snippet: driver.massMemory.load.item.set(item_path = '1', file_name = '1') \n
+		Snippet: driver.massMemory.load.item.set(item_path = '1', filename = '1') \n
 		Executes a partial recall. That means, restores a selected part of a save file. You can restore all settings of a
 		specific application instance. Or you can restore the list mode settings of a specific measurement application instance. \n
 			:param item_path: No help available
-			:param file_name: No help available
+			:param filename: No help available
 		"""
-		param = ArgSingleList().compose_cmd_string(ArgSingle('item_path', item_path, DataType.String), ArgSingle('file_name', file_name, DataType.String))
+		param = ArgSingleList().compose_cmd_string(ArgSingle('item_path', item_path, DataType.String), ArgSingle('filename', filename, DataType.String))
 		self._core.io.write(f'MMEMory:LOAD:ITEM {param}'.rstrip())
