@@ -13,14 +13,14 @@ class State:
 		self._core = core
 		self._base = CommandsGroup("state", core, parent)
 
-	def set(self, sav_rcl_state_number: float, file_name: str, msus: str = None) -> None:
+	def set(self, sav_rcl_state_number: float, filename: str, msus: str = None) -> None:
 		"""SCPI: MMEMory:LOAD:STATe \n
-		Snippet: driver.massMemory.load.state.set(sav_rcl_state_number = 1.0, file_name = '1', msus = '1') \n
+		Snippet: driver.massMemory.load.state.set(sav_rcl_state_number = 1.0, filename = '1', msus = '1') \n
 		Loads the instrument settings from the specified file to the specified internal memory. After the file has been loaded,
 		the settings must be activated using a *RCL command. For more convenience, see method RsCMPX_Base.MassMemory.recall. \n
 			:param sav_rcl_state_number: No help available
-			:param file_name: No help available
+			:param filename: No help available
 			:param msus: No help available
 		"""
-		param = ArgSingleList().compose_cmd_string(ArgSingle('sav_rcl_state_number', sav_rcl_state_number, DataType.Float), ArgSingle('file_name', file_name, DataType.String), ArgSingle('msus', msus, DataType.String, True))
+		param = ArgSingleList().compose_cmd_string(ArgSingle('sav_rcl_state_number', sav_rcl_state_number, DataType.Float), ArgSingle('filename', filename, DataType.String), ArgSingle('msus', msus, DataType.String, True))
 		self._core.io.write(f'MMEMory:LOAD:STATe {param}'.rstrip())
