@@ -13,14 +13,14 @@ class Macro:
 		self._core = core
 		self._base = CommandsGroup("macro", core, parent)
 
-	def set(self, label: str, file_name: str, msus: str = None) -> None:
+	def set(self, label: str, filename: str, msus: str = None) -> None:
 		"""SCPI: MMEMory:STORe:MACRo \n
-		Snippet: driver.massMemory.store.macro.set(label = '1', file_name = '1', msus = '1') \n
+		Snippet: driver.massMemory.store.macro.set(label = '1', filename = '1', msus = '1') \n
 		Stores the contents of a macro to a file. If the file exists, it is overwritten. If the file does not exist, it is
 		created. \n
 			:param label: No help available
-			:param file_name: No help available
+			:param filename: No help available
 			:param msus: No help available
 		"""
-		param = ArgSingleList().compose_cmd_string(ArgSingle('label', label, DataType.String), ArgSingle('file_name', file_name, DataType.String), ArgSingle('msus', msus, DataType.String, True))
+		param = ArgSingleList().compose_cmd_string(ArgSingle('label', label, DataType.String), ArgSingle('filename', filename, DataType.String), ArgSingle('msus', msus, DataType.String, True))
 		self._core.io.write(f'MMEMory:STORe:MACRo {param}'.rstrip())
