@@ -13,15 +13,15 @@ class State:
 		self._core = core
 		self._base = CommandsGroup("state", core, parent)
 
-	def set(self, sav_rcl_state_number: int, file_name: str, msus: str = None) -> None:
+	def set(self, sav_rcl_state_number: int, filename: str, msus: str = None) -> None:
 		"""SCPI: MMEMory:STORe:STATe \n
-		Snippet: driver.massMemory.store.state.set(sav_rcl_state_number = 1, file_name = '1', msus = '1') \n
+		Snippet: driver.massMemory.store.state.set(sav_rcl_state_number = 1, filename = '1', msus = '1') \n
 		Stores the instrument settings from the specified internal memory to the specified file. To store the current instrument
 		settings to a file, use first *SAV <MemoryNumber> to store the settings to the memory. Then use this command to store the
 		settings from the memory to a file. For more convenience, see method RsCMPX_Base.MassMemory.save. \n
 			:param sav_rcl_state_number: No help available
-			:param file_name: No help available
+			:param filename: No help available
 			:param msus: No help available
 		"""
-		param = ArgSingleList().compose_cmd_string(ArgSingle('sav_rcl_state_number', sav_rcl_state_number, DataType.Integer), ArgSingle('file_name', file_name, DataType.String), ArgSingle('msus', msus, DataType.String, True))
+		param = ArgSingleList().compose_cmd_string(ArgSingle('sav_rcl_state_number', sav_rcl_state_number, DataType.Integer), ArgSingle('filename', filename, DataType.String), ArgSingle('msus', msus, DataType.String, True))
 		self._core.io.write(f'MMEMory:STORe:STATe {param}'.rstrip())
