@@ -20,13 +20,13 @@ class Password:
 			self._cenable = Cenable(self._core, self._base)
 		return self._cenable
 
-	def set_cdisable(self, usermode: enums.UserRole) -> None:
+	def set_cdisable(self, user_mode: enums.UserRole) -> None:
 		"""SCPI: SYSTem:BASE:PASSword:CDISable \n
-		Snippet: driver.system.base.password.set_cdisable(usermode = enums.UserRole.ADMin) \n
+		Snippet: driver.system.base.password.set_cdisable(user_mode = enums.UserRole.ADMin) \n
 		No command help available \n
-			:param usermode: No help available
+			:param user_mode: No help available
 		"""
-		param = Conversions.enum_scalar_to_str(usermode, enums.UserRole)
+		param = Conversions.enum_scalar_to_str(user_mode, enums.UserRole)
 		self._core.io.write(f'SYSTem:BASE:PASSword:CDISable {param}')
 
 	def clone(self) -> 'Password':
