@@ -17,7 +17,7 @@ class Vresource:
 		Snippet: value: str = driver.system.communicate.gpib.vresource.get(gpibInstance = repcap.GpibInstance.Default) \n
 		No command help available \n
 			:param gpibInstance: optional repeated capability selector. Default value: Inst1 (settable in the interface 'Gpib')
-			:return: visaresource: No help available"""
+			:return: visa_resource: No help available"""
 		gpibInstance_cmd_val = self._base.get_repcap_cmd_value(gpibInstance, repcap.GpibInstance)
 		response = self._core.io.query_str(f'SYSTem:COMMunicate:GPIB{gpibInstance_cmd_val}:VRESource?')
 		return trim_str_response(response)
