@@ -17,7 +17,7 @@ class Vresource:
 		Snippet: value: str = driver.system.communicate.hislip.vresource.get(hislipInstance = repcap.HislipInstance.Default) \n
 		Queries the VISA resource string for the HiSLIP protocol. \n
 			:param hislipInstance: optional repeated capability selector. Default value: Inst1 (settable in the interface 'Hislip')
-			:return: visaresource: No help available"""
+			:return: visa_resource: No help available"""
 		hislipInstance_cmd_val = self._base.get_repcap_cmd_value(hislipInstance, repcap.HislipInstance)
 		response = self._core.io.query_str(f'SYSTem:COMMunicate:HISLip{hislipInstance_cmd_val}:VRESource?')
 		return trim_str_response(response)
