@@ -17,7 +17,7 @@ class Vresource:
 		Snippet: value: str = driver.system.communicate.rsib.vresource.get(rsibInstance = repcap.RsibInstance.Default) \n
 		No command help available \n
 			:param rsibInstance: optional repeated capability selector. Default value: Inst1 (settable in the interface 'Rsib')
-			:return: visaresource: No help available"""
+			:return: visa_resource: No help available"""
 		rsibInstance_cmd_val = self._base.get_repcap_cmd_value(rsibInstance, repcap.RsibInstance)
 		response = self._core.io.query_str(f'SYSTem:COMMunicate:RSIB{rsibInstance_cmd_val}:VRESource?')
 		return trim_str_response(response)
