@@ -17,7 +17,7 @@ class Vresource:
 		Snippet: value: str = driver.system.communicate.socket.vresource.get(socketInstance = repcap.SocketInstance.Default) \n
 		Queries the VISA resource string for direct socket communication. \n
 			:param socketInstance: optional repeated capability selector. Default value: Inst1 (settable in the interface 'Socket')
-			:return: visaresource: No help available"""
+			:return: visa_resource: No help available"""
 		socketInstance_cmd_val = self._base.get_repcap_cmd_value(socketInstance, repcap.SocketInstance)
 		response = self._core.io.query_str(f'SYSTem:COMMunicate:SOCKet{socketInstance_cmd_val}:VRESource?')
 		return trim_str_response(response)
