@@ -15,7 +15,7 @@ class Usb:
 		"""SCPI: SYSTem:COMMunicate:USB:VRESource \n
 		Snippet: value: str = driver.system.communicate.usb.get_vresource() \n
 		Queries the VISA resource string of the USB interface. \n
-			:return: visaresource: No help available
+			:return: visa_resource: No help available
 		"""
 		response = self._core.io.query_str('SYSTem:COMMunicate:USB:VRESource?')
 		return trim_str_response(response)
