@@ -17,7 +17,7 @@ class Vresource:
 		Snippet: value: str = driver.system.communicate.vxi.vresource.get(vxiInstance = repcap.VxiInstance.Default) \n
 		Queries the VISA resource string for the VXI-11 protocol. \n
 			:param vxiInstance: optional repeated capability selector. Default value: Inst1 (settable in the interface 'Vxi')
-			:return: visaresource: No help available"""
+			:return: visa_resource: No help available"""
 		vxiInstance_cmd_val = self._base.get_repcap_cmd_value(vxiInstance, repcap.VxiInstance)
 		response = self._core.io.query_str(f'SYSTem:COMMunicate:VXI{vxiInstance_cmd_val}:VRESource?')
 		return trim_str_response(response)
