@@ -19,7 +19,7 @@ class Source:
 		Snippet: value: List[str] = driver.trigger.base.eout.catalog.source.get(eout = repcap.Eout.Default) \n
 		No command help available \n
 			:param eout: optional repeated capability selector. Default value: Eout1 (settable in the interface 'Eout')
-			:return: sourcelist: No help available"""
+			:return: source_list: No help available"""
 		eout_cmd_val = self._base.get_repcap_cmd_value(eout, repcap.Eout)
 		response = self._core.io.query_str(f'TRIGger:BASE:EOUT{eout_cmd_val}:CATalog:SOURce?')
 		return Conversions.str_to_str_list(response)
