@@ -17,7 +17,7 @@ class Catalog:
 		"""SCPI: TRIGger:BASE:EXTB:CATalog:SOURce \n
 		Snippet: value: List[str] = driver.trigger.base.extB.catalog.get_source() \n
 		Lists all trigger source values that can be set using TRIGger:BASE:EXTA|EXTB:SOURce. \n
-			:return: sourcelist: Comma-separated list of strings, one string per supported value
+			:return: source_list: Comma-separated list of strings, one string per supported value
 		"""
 		response = self._core.io.query_str('TRIGger:BASE:EXTB:CATalog:SOURce?')
 		return Conversions.str_to_str_list(response)
